@@ -12,6 +12,7 @@
 #include "katefilebrowser.h"
 
 #include "katebookmarkhandler.h"
+#include "katefileactions.h"
 
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
@@ -20,23 +21,14 @@
 #include <KActionMenu>
 #include <KApplicationTrader>
 #include <KConfigGroup>
-#include <KDirOperator>
 #include <KFilePlacesModel>
 #include <KHistoryComboBox>
-#include <KIO/ApplicationLauncherJob>
-#include <kio_version.h>
-#include <kwidgetsaddons_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-#include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <KToolBar>
 #include <KUrlNavigator>
-#include <kio_version.h>
+#include <kwidgetsaddons_version.h>
 
 #include <QAbstractItemView>
 #include <QAction>
@@ -79,7 +71,11 @@ KateFileBrowser::KateFileBrowser(KTextEditor::MainWindow *mainWindow, QWidget *p
 
     m_dirOperator = new KDirOperator(QUrl(), this);
     // Default to a view with only one column since columns are auto-sized
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     m_dirOperator->setView(KFile::Tree);
+#else
+    m_dirOperator->setViewMode(KFile::Tree);
+#endif
     m_dirOperator->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
     m_dirOperator->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
     mainLayout->addWidget(m_dirOperator);
@@ -179,7 +175,11 @@ void KateFileBrowser::setupToolbar()
 void KateFileBrowser::readSessionConfig(const KConfigGroup &cg)
 {
     m_dirOperator->readConfig(cg);
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     m_dirOperator->setView(KFile::Default);
+#else
+    m_dirOperator->setViewMode(KFile::Default);
+#endif
 
     m_urlNavigator->setLocationUrl(cg.readEntry("location", QUrl::fromLocalFile(QDir::homePath())));
     setDir(cg.readEntry("location", QUrl::fromLocalFile(QDir::homePath())));
@@ -331,18 +331,8 @@ void KateFileBrowser::openWithMenuAction(QAction *a)
 {
     const QString application = a->data().toStringList().first();
     const QString fileName = a->data().toStringList().last();
-    const QList<QUrl> list({QUrl(fileName)});
 
-    KService::Ptr app = KService::serviceByDesktopPath(application);
-    // If app is null, ApplicationLauncherJob will invoke the open-with dialog
-    auto *job = new KIO::ApplicationLauncherJob(app);
-    job->setUrls(list);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#endif
-    job->start();
+    KateFileActions::showOpenWithMenu(this, QUrl(fileName), a);
 }
 // END Public Slots
 
