@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KATE_FILETREE_PLUGIN_H
-#define KATE_FILETREE_PLUGIN_H
+#pragma once
 
 #include <QTimer>
 
@@ -104,6 +103,11 @@ public:
     bool hasLocalPrefs() const;
     void setHasLocalPrefs(bool);
 
+    KTextEditor::MainWindow *mainWindow() const
+    {
+        return m_mainWindow;
+    }
+
 protected:
     void setupActions();
 
@@ -137,5 +141,3 @@ private Q_SLOTS:
     void slotWidgetCreated(QWidget *);
     void slotWidgetRemoved(QWidget *);
 };
-
-#endif // KATE_FILETREE_PLUGIN_H
