@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KateGitBlamePlugin_h
-#define KateGitBlamePlugin_h
+#pragma once
 
 #include "gitblametooltip.h"
 
@@ -101,11 +100,6 @@ private:
     void startShowProcess(const QUrl &url, const QString &hash);
     void showFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
-    void createToolView();
-    void hideToolView();
-
-    void showDiffForFile(const QByteArray &diffContents, const QString &file);
-
     const CommitInfo &blameGetUpdateInfo(int lineNr);
 
     KTextEditor::MainWindow *m_mainWindow;
@@ -122,9 +116,6 @@ private:
     GitBlameTooltip m_tooltip;
     QString m_showHash;
     class CommitDiffTreeView *m_commitFilesView;
-    std::unique_ptr<QWidget> m_toolView;
     QPointer<KTextEditor::View> m_diffView;
     QTimer m_startBlameTimer;
 };
-
-#endif // KateGitBlamePlugin_h
