@@ -8,7 +8,6 @@
 #include "keyboardmacrospluginview.h"
 #include "keycombination.h"
 #include "ktexteditor_utils.h"
-#include "macro.h"
 
 #include <QApplication>
 #include <QCoreApplication>
@@ -19,24 +18,14 @@
 #include <QJsonObject>
 #include <QJsonParseError>
 #include <QKeyEvent>
-#include <QKeySequence>
-#include <QList>
 #include <QLoggingCategory>
-#include <QObject>
-#include <QPointer>
 #include <QSaveFile>
 #include <QStandardPaths>
-#include <QString>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-#include <KTextEditor/Application>
 #include <KTextEditor/Editor>
-#include <KTextEditor/MainWindow>
-#include <KTextEditor/Message>
-#include <KTextEditor/Plugin>
-#include <KTextEditor/View>
 
 Q_LOGGING_CATEGORY(KM_DBG, "kate.plugin.keyboardmacros", QtWarningMsg)
 
@@ -126,12 +115,8 @@ void KeyboardMacrosPlugin::saveNamedMacros()
 
 void KeyboardMacrosPlugin::sendMessage(const QString &text, bool error)
 {
-    QVariantMap genericMessage;
-    genericMessage.insert(QStringLiteral("type"), error ? QStringLiteral("Error") : QStringLiteral("Info"));
-    genericMessage.insert(QStringLiteral("category"), i18n("Keyboard Macros"));
-    genericMessage.insert(QStringLiteral("categoryIcon"), QIcon::fromTheme(QStringLiteral("input-keyboard")));
-    genericMessage.insert(QStringLiteral("text"), text);
-    Utils::showMessage(genericMessage, KTextEditor::Editor::instance()->application()->activeMainWindow());
+    const auto icon = QIcon::fromTheme(QStringLiteral("input-keyboard"));
+    Utils::showMessage(text, icon, i18n("Keyboard Macros"), error ? MessageType::Error : MessageType::Info);
 }
 
 void KeyboardMacrosPlugin::displayMessage(const QString &text, KTextEditor::Message::MessageType type)
