@@ -5,8 +5,7 @@
     SPDX-License-Identifier: MIT
 */
 
-#ifndef LSPCLIENTHOVER_H
-#define LSPCLIENTHOVER_H
+#pragma once
 
 class LSPClientServerManager;
 class LSPClientServer;
@@ -21,17 +20,15 @@ class LSPClientHover : public QObject, public KTextEditor::TextHintProvider
 
 public:
     // implementation factory method
-    static LSPClientHover *new_(QSharedPointer<LSPClientServerManager> manager);
+    static LSPClientHover *new_(std::shared_ptr<LSPClientServerManager> manager);
 
     LSPClientHover()
         : KTextEditor::TextHintProvider()
     {
     }
 
-    virtual void setServer(QSharedPointer<LSPClientServer> server) = 0;
+    virtual void setServer(std::shared_ptr<LSPClientServer> server) = 0;
 
     // support additional parameters besides the usual interface signature
     virtual QString showTextHint(KTextEditor::View *view, const KTextEditor::Cursor &position, bool manual) = 0;
 };
-
-#endif
