@@ -45,6 +45,8 @@ static const QString CONFIG_SIGNATURE_HELP{QStringLiteral("SignatureHelp")};
 static const QString CONFIG_AUTO_IMPORT{QStringLiteral("AutoImport")};
 static const QString CONFIG_ALLOWED_COMMANDS{QStringLiteral("AllowedServerCommandLines")};
 static const QString CONFIG_BLOCKED_COMMANDS{QStringLiteral("BlockedServerCommandLines")};
+static const QString CONFIG_FORMAT_ON_SAVE{QStringLiteral("FormatOnSave")};
+static const QString CONFIG_INLAY_HINT{QStringLiteral("InlayHints")};
 
 K_PLUGIN_FACTORY_WITH_JSON(LSPClientPluginFactory, "lspclientplugin.json", registerPlugin<LSPClientPlugin>();)
 
@@ -123,15 +125,13 @@ void LSPClientPlugin::readConfig()
     m_incrementalSync = config.readEntry(CONFIG_INCREMENTAL_SYNC, false);
     m_highlightGoto = config.readEntry(CONFIG_HIGHLIGHT_GOTO, true);
     m_diagnostics = config.readEntry(CONFIG_DIAGNOSTICS, true);
-    m_diagnosticsHighlight = config.readEntry(CONFIG_DIAGNOSTICS_HIGHLIGHT, true);
-    m_diagnosticsMark = config.readEntry(CONFIG_DIAGNOSTICS_MARK, true);
-    m_diagnosticsHover = config.readEntry(CONFIG_DIAGNOSTICS_HOVER, true);
-    m_diagnosticsSize = config.readEntry(CONFIG_DIAGNOSTICS_SIZE, 1024);
     m_messages = config.readEntry(CONFIG_MESSAGES, true);
     m_configPath = config.readEntry(CONFIG_SERVER_CONFIG, QUrl());
     m_semanticHighlighting = config.readEntry(CONFIG_SEMANTIC_HIGHLIGHTING, true);
     m_signatureHelp = config.readEntry(CONFIG_SIGNATURE_HELP, true);
     m_autoImport = config.readEntry(CONFIG_AUTO_IMPORT, true);
+    m_fmtOnSave = config.readEntry(CONFIG_FORMAT_ON_SAVE, false);
+    m_inlayHints = config.readEntry(CONFIG_INLAY_HINT, false);
 
     // read allow + block lists as two separate keys, let block always win
     const auto allowed = config.readEntry(CONFIG_ALLOWED_COMMANDS, QStringList());
@@ -162,15 +162,13 @@ void LSPClientPlugin::writeConfig() const
     config.writeEntry(CONFIG_INCREMENTAL_SYNC, m_incrementalSync);
     config.writeEntry(CONFIG_HIGHLIGHT_GOTO, m_highlightGoto);
     config.writeEntry(CONFIG_DIAGNOSTICS, m_diagnostics);
-    config.writeEntry(CONFIG_DIAGNOSTICS_HIGHLIGHT, m_diagnosticsHighlight);
-    config.writeEntry(CONFIG_DIAGNOSTICS_MARK, m_diagnosticsMark);
-    config.writeEntry(CONFIG_DIAGNOSTICS_HOVER, m_diagnosticsHover);
-    config.writeEntry(CONFIG_DIAGNOSTICS_SIZE, m_diagnosticsSize);
     config.writeEntry(CONFIG_MESSAGES, m_messages);
     config.writeEntry(CONFIG_SERVER_CONFIG, m_configPath);
     config.writeEntry(CONFIG_SEMANTIC_HIGHLIGHTING, m_semanticHighlighting);
     config.writeEntry(CONFIG_SIGNATURE_HELP, m_signatureHelp);
     config.writeEntry(CONFIG_AUTO_IMPORT, m_autoImport);
+    config.writeEntry(CONFIG_FORMAT_ON_SAVE, m_fmtOnSave);
+    config.writeEntry(CONFIG_INLAY_HINT, m_inlayHints);
 
     // write allow + block lists as two separate keys
     QStringList allowed, blocked;
