@@ -25,7 +25,6 @@
 #include <QJsonParseError>
 #include <QMimeData>
 #include <QPlainTextDocumentLayout>
-#include <QPointer>
 #include <utility>
 
 #include <KIO/CopyJob>
@@ -117,14 +116,9 @@ KateProject::KateProject(QThreadPool &threadPool, KateProjectPlugin *plugin, con
     : m_threadPool(threadPool)
     , m_plugin(plugin)
     , m_fileBacked(true)
-    , m_fileName(QFileInfo(fileName).canonicalFilePath())
-    , m_baseDir(QFileInfo(fileName).canonicalPath())
+    , m_fileName(QFileInfo(fileName).absoluteFilePath())
+    , m_baseDir(QFileInfo(fileName).absolutePath())
 {
-    // if canonicalFilePath already returned empty string, no need to try to load this
-    if (m_fileName.isEmpty()) {
-        return;
-    }
-
     // ensure we get notified for project file changes
     connect(&m_plugin->fileWatcher(), &QFileSystemWatcher::fileChanged, this, &KateProject::slotFileChanged);
     m_plugin->fileWatcher().addPath(m_fileName);
@@ -139,8 +133,8 @@ KateProject::KateProject(QThreadPool &threadPool, KateProjectPlugin *plugin, con
     : m_threadPool(threadPool)
     , m_plugin(plugin)
     , m_fileBacked(false)
-    , m_fileName(QDir(QDir(directory).canonicalPath()).filePath(QStringLiteral(".kateproject")))
-    , m_baseDir(QDir(directory).canonicalPath())
+    , m_fileName(QDir(QDir(directory).absolutePath()).filePath(QStringLiteral(".kateproject")))
+    , m_baseDir(QDir(directory).absolutePath())
     , m_globalProject(globalProject)
 {
     // try to load the project map, will start worker thread, too
@@ -294,7 +288,7 @@ bool KateProject::load(const QVariantMap &globalProject, bool force)
      */
     const auto baseDir = globalProject[QStringLiteral("directory")].toString();
     if (!baseDir.isEmpty()) {
-        m_baseDir = QFileInfo(QFileInfo(m_fileName).dir(), baseDir).canonicalFilePath();
+        m_baseDir = QFileInfo(QFileInfo(m_fileName).dir(), baseDir).absoluteFilePath();
     }
 
     /**
@@ -323,6 +317,14 @@ bool KateProject::load(const QVariantMap &globalProject, bool force)
         }
     }
 
+    auto column = m_model.invisibleRootItem()->takeColumn(0);
+    m_untrackedDocumentsRoot = nullptr;
+    m_file2Item.reset();
+    auto deleter = QRunnable::create([column = std::move(column)] {
+        qDeleteAll(column);
+    });
+    m_threadPool.start(deleter);
+
     // let's run the stuff in our own thread pool
     // do manual queued connect, as only run() is done in extra thread, object stays in this one
     auto w = new KateProjectWorker(m_baseDir, indexDir, m_projectMap, force);
@@ -338,13 +340,12 @@ void KateProject::loadProjectDone(const KateProjectSharedQStandardItem &topLevel
 {
     m_model.clear();
     m_model.invisibleRootItem()->appendColumn(topLevel->takeColumn(0));
-
+    m_untrackedDocumentsRoot = nullptr;
     m_file2Item = std::move(file2Item);
 
     /**
      * readd the documents that are open atm
      */
-    m_untrackedDocumentsRoot = nullptr;
     for (auto i = m_documents.constBegin(); i != m_documents.constEnd(); i++) {
         registerDocument(i.key());
     }
@@ -568,12 +569,15 @@ void KateProject::unregisterDocument(KTextEditor::Document *document)
         return;
     }
 
+    // ignore further updates but clear state once
     disconnect(document, &KTextEditor::Document::modifiedChanged, this, &KateProject::slotModifiedChanged);
-
     const QString &file = m_documents.value(document);
+    KateProjectItem *item = static_cast<KateProjectItem *>(itemForFile(file));
+    if (item) {
+        item->slotModifiedChanged(nullptr);
+    }
 
     if (m_untrackedDocumentsRoot) {
-        KateProjectItem *item = static_cast<KateProjectItem *>(itemForFile(file));
         if (item && item->data(Qt::UserRole + 3).toBool()) {
             unregisterUntrackedItem(item);
             m_file2Item->remove(file);
