@@ -5,8 +5,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KATE_PROJECT_H
-#define KATE_PROJECT_H
+#pragma once
 
 #include "kateprojectindex.h"
 #include "kateprojectitem.h"
@@ -15,8 +14,8 @@
 
 #include <QHash>
 #include <QPointer>
-#include <QSharedPointer>
 #include <QTextDocument>
+#include <memory>
 
 class KateProjectModel : public QStandardItemModel
 {
@@ -41,13 +40,13 @@ private:
  * Shared pointer data types.
  * Used to pass pointers over queued connected slots
  */
-typedef QSharedPointer<QStandardItem> KateProjectSharedQStandardItem;
+typedef std::shared_ptr<QStandardItem> KateProjectSharedQStandardItem;
 Q_DECLARE_METATYPE(KateProjectSharedQStandardItem)
 
-typedef QSharedPointer<QHash<QString, KateProjectItem *>> KateProjectSharedQHashStringItem;
+typedef std::shared_ptr<QHash<QString, KateProjectItem *>> KateProjectSharedQHashStringItem;
 Q_DECLARE_METATYPE(KateProjectSharedQHashStringItem)
 
-typedef QSharedPointer<KateProjectIndex> KateProjectSharedProjectIndex;
+typedef std::shared_ptr<KateProjectIndex> KateProjectSharedProjectIndex;
 Q_DECLARE_METATYPE(KateProjectSharedProjectIndex)
 
 class KateProjectPlugin;
@@ -211,7 +210,7 @@ public:
      */
     KateProjectIndex *projectIndex()
     {
-        return m_projectIndex.data();
+        return m_projectIndex.get();
     }
 
     KateProjectPlugin *plugin()
@@ -379,5 +378,3 @@ private:
      */
     QVariantMap m_globalProject;
 };
-
-#endif
