@@ -6,6 +6,8 @@
  */
 
 #include "kateprojectpluginview.h"
+#include "branchcheckoutdialog.h"
+#include "currentgitbranchbutton.h"
 #include "fileutil.h"
 #include "gitprocess.h"
 #include "gitwidget.h"
@@ -14,6 +16,7 @@
 #include "kateprojectinfoviewindex.h"
 #include "kateprojectplugin.h"
 #include "kateprojectview.h"
+#include "ktexteditor_utils.h"
 
 #include <KTextEditor/Command>
 #include <ktexteditor/application.h>
@@ -73,6 +76,7 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
      * create the combo + buttons for the toolViews + stacked widgets
      */
     m_projectsCombo = new QComboBox(m_toolView);
+    m_projectsCombo->setToolTip(i18n("Open projects list"));
     m_projectsCombo->setFrame(false);
     m_reloadButton = new QToolButton(m_toolView);
     m_reloadButton->setAutoRaise(true);
@@ -80,6 +84,7 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
     m_reloadButton->setToolTip(i18n("Reload project"));
     m_closeProjectButton = new QToolButton(m_toolView);
     m_closeProjectButton->setAutoRaise(true);
+    m_closeProjectButton->setToolTip(i18n("Close project"));
     m_closeProjectButton->setIcon(QIcon::fromTheme(QStringLiteral(PROJECTCLOSEICON)));
     QHBoxLayout *layout = new QHBoxLayout();
     layout->setSpacing(0);
@@ -125,8 +130,10 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
         }
     });
 
-    connect(&m_gitChangedWatcher, &QFileSystemWatcher::fileChanged, this, [this] {
-        slotUpdateStatus(true);
+    connect(&m_plugin->fileWatcher(), &QFileSystemWatcher::fileChanged, this, [this](const QString &path) {
+        if (m_gitChangedWatcherFile == path) {
+            slotUpdateStatus(true);
+        }
     });
 
     /**
@@ -207,6 +214,13 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
 
     m_gotoSymbolActionAppMenu = a = actionCollection()->addAction(KStandardAction::Goto, QStringLiteral("projects_goto_symbol"), this, SLOT(slotGotoSymbol()));
 
+    auto chckbrAct = actionCollection()->addAction(QStringLiteral("checkout_branch"), this, [this] {
+        BranchCheckoutDialog bd(mainWindow()->window(), this, projectBaseDir());
+        bd.openDialog();
+    });
+    chckbrAct->setIcon(QIcon::fromTheme(QStringLiteral("vcs-branch")));
+    chckbrAct->setText(i18n("Checkout Git Branch"));
+
     // popup menu
     auto popup = new KActionMenu(i18n("Project"), this);
     actionCollection()->addAction(QStringLiteral("popup_project"), popup);
@@ -274,6 +288,11 @@ KateProjectPluginView::~KateProjectPluginView()
      * cu gui client
      */
     m_mainWindow->guiFactory()->removeClient(this);
+
+    // Don't watch what nobody use, the old project...
+    if (!m_gitChangedWatcherFile.isEmpty()) {
+        m_plugin->fileWatcher().removePath(m_gitChangedWatcherFile);
+    }
 }
 
 void KateProjectPluginView::slotConfigUpdated()
@@ -312,7 +331,7 @@ QPair<KateProjectView *, KateProjectInfoView *> KateProjectPluginView::viewForPr
     /**
      * create new views
      */
-    KateProjectView *view = new KateProjectView(this, project, m_mainWindow);
+    KateProjectView *view = new KateProjectView(this, project);
     KateProjectInfoView *infoView = new KateProjectInfoView(this, project);
     GitWidget *gitView = new GitWidget(project, m_mainWindow, this);
 
@@ -514,9 +533,11 @@ void KateProjectPluginView::slotCurrentChanged(int index)
     }
 
     // Don't watch what nobody use, the old project...
-    if (!m_gitChangedWatcher.files().isEmpty()) {
-        m_gitChangedWatcher.removePaths(m_gitChangedWatcher.files());
+    if (!m_gitChangedWatcherFile.isEmpty()) {
+        m_plugin->fileWatcher().removePath(m_gitChangedWatcherFile);
+        m_gitChangedWatcherFile.clear();
     }
+
     // ...and start watching the new one
     slotUpdateStatus(true);
 
@@ -714,9 +735,11 @@ void KateProjectPluginView::slotHandleProjectClosing(KateProject *project)
     m_projectsComboGit->removeItem(index);
 
     // Stop watching what no one is interesting anymore
-    if (!m_gitChangedWatcher.files().isEmpty()) {
-        m_gitChangedWatcher.removePaths(m_gitChangedWatcher.files());
+    if (!m_gitChangedWatcherFile.isEmpty()) {
+        m_plugin->fileWatcher().removePath(m_gitChangedWatcherFile);
+        m_gitChangedWatcherFile.clear();
     }
+
     // inform onward
     Q_EMIT pluginProjectRemoved(project->baseDir(), project->name());
 
@@ -805,9 +828,12 @@ void KateProjectPluginView::slotUpdateStatus(bool visible)
     if (auto widget = static_cast<GitWidget *>(m_stackedGitViews->currentWidget())) {
         // To support separate-git-dir always use dotGitPath
         // We need to add the path every time again because it's always a different file
-        const auto path = widget->indexPath();
-        if (!path.isEmpty()) {
-            m_gitChangedWatcher.addPath(path);
+        if (!m_gitChangedWatcherFile.isEmpty()) {
+            m_plugin->fileWatcher().removePath(m_gitChangedWatcherFile);
+        }
+        m_gitChangedWatcherFile = widget->indexPath();
+        if (!m_gitChangedWatcherFile.isEmpty()) {
+            m_plugin->fileWatcher().addPath(m_gitChangedWatcherFile);
         }
         widget->updateStatus();
     }
@@ -900,4 +926,21 @@ void KateProjectPluginView::slotActivateProject(KateProject *project)
     }
 }
 
+void KateProjectPluginView::updateGitBranchButton(KateProject *project)
+{
+    if (!m_branchBtn) {
+        m_branchBtn.reset(new CurrentGitBranchButton(mainWindow(), nullptr));
+        auto a = actionCollection()->action(QStringLiteral("checkout_branch"));
+        Q_ASSERT(a);
+        m_branchBtn->setDefaultAction(a);
+        Utils::insertWidgetInStatusbar(m_branchBtn.get(), mainWindow());
+    }
+
+    if (!project || project->baseDir() != projectBaseDir()) {
+        return;
+    }
+
+    static_cast<CurrentGitBranchButton *>(m_branchBtn.get())->refresh();
+}
+
 #include "kateprojectpluginview.moc"
