@@ -639,6 +639,15 @@ bool KateMainWindow::queryClose_internal(KTextEditor::Document *doc, KateMainWin
                                 modifiedDocuments.end());
     }
 
+    // Remove all docs for which doc::queryClose == true. These can be untitled
+    // docs for e.g.,
+    modifiedDocuments.erase(std::remove_if(modifiedDocuments.begin(),
+                                           modifiedDocuments.end(),
+                                           [](KTextEditor::Document *d) {
+                                               return d->queryClose();
+                                           }),
+                            modifiedDocuments.end());
+
     bool shutdown = modifiedDocuments.empty();
     if (!shutdown) {
         shutdown = KateSaveModifiedDialog::queryClose(this, modifiedDocuments);
