@@ -1093,7 +1093,7 @@ void Sidebar::setVisible(bool visible)
         return;
     }
 
-    QWidget::setVisible(visible);
+    QSplitter::setVisible(visible);
 }
 
 void Sidebar::buttonPopupActivate(QAction *a)
@@ -1326,13 +1326,17 @@ MainWindow::MainWindow(QWidget *parentWidget)
 
     // bottom side bar spans full windows, include status bar, too
     m_sidebars[KMultiTabBar::Bottom] = std::make_unique<Sidebar>(KMultiTabBar::Bottom, m_vSplitter, this, vb);
-    auto bottomHBoxLaout = new QHBoxLayout;
-    bottomHBoxLaout->addWidget(m_sidebars[KMultiTabBar::Bottom].get());
+    m_bottomSidebarLayout = new QHBoxLayout;
+    m_bottomSidebarLayout->addWidget(m_sidebars[KMultiTabBar::Bottom].get());
     m_statusBarStackedWidget = new QStackedWidget(this);
     m_statusBarStackedWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    bottomHBoxLaout->addWidget(m_statusBarStackedWidget);
-    bottomHBoxLaout->setStretch(0, 100);
-    toplevelVBox->addLayout(bottomHBoxLaout);
+    // button that shows git branch
+    // m_branchLabel = new CurrentGitBranchButton(this);
+    // m_bottomSidebarLayout->addWidget(m_branchLabel);
+    // widget that hold statusbar of active kte-view
+    m_bottomSidebarLayout->addWidget(m_statusBarStackedWidget);
+    m_bottomSidebarLayout->setStretch(0, 100);
+    toplevelVBox->addLayout(m_bottomSidebarLayout);
 
     // ensure proper toolview style
     setToolViewStyle(KMultiTabBar::KDEV3ICON);
@@ -1358,6 +1362,14 @@ QWidget *MainWindow::centralWidget() const
     return m_centralWidget;
 }
 
+void MainWindow::insertWidgetBeforeStatusbar(QWidget *widget)
+{
+    Q_ASSERT(m_bottomSidebarLayout);
+    const auto idxOfStatusbar = m_bottomSidebarLayout->indexOf(m_statusBarStackedWidget);
+    Q_ASSERT(idxOfStatusbar != -1);
+    m_bottomSidebarLayout->insertWidget(idxOfStatusbar, widget);
+}
+
 ToolView *MainWindow::createToolView(KTextEditor::Plugin *plugin,
                                      const QString &identifier,
                                      KMultiTabBar::KMultiTabBarPosition pos,
@@ -1413,19 +1425,24 @@ void MainWindow::toolViewDeleted(ToolView *widget)
     m_toolviews.erase(widget->id);
 }
 
-void MainWindow::setSidebarsVisibleInternal(bool visible, bool noWarning)
+void MainWindow::setSidebarsVisibleInternal(bool visible, bool hideFullySilent)
 {
     bool old_visible = m_sidebarsVisible;
     m_sidebarsVisible = visible;
 
     for (auto &sidebar : m_sidebars) {
         sidebar->setVisible(visible);
+
+        // fully hide the stuff, see bug 464320
+        if (hideFullySilent) {
+            sidebar->collapseSidebar();
+        }
     }
 
     m_guiClient->updateSidebarsVisibleAction();
 
     // show information message box, if the users hides the sidebars
-    if (!noWarning && old_visible && (!m_sidebarsVisible)) {
+    if (!hideFullySilent && old_visible && (!m_sidebarsVisible)) {
         KMessageBox::information(this,
                                  i18n("<qt>You are about to hide the sidebars. With "
                                       "hidden sidebars it is not possible to directly "
