@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KATESTASHMANAGER_H
-#define KATESTASHMANAGER_H
+#pragma once
 
 #include "katesession.h"
 #include "kconfiggroup.h"
@@ -23,7 +22,7 @@ class KateStashManager : QObject
 public:
     KateStashManager(QObject *parent = nullptr);
 
-    bool stashUnsavedChanges()
+    bool stashUnsavedChanges() const
     {
         return m_stashUnsavedChanges;
     }
@@ -33,7 +32,7 @@ public:
         m_stashUnsavedChanges = stashUnsavedChanges;
     }
 
-    bool stashNewUnsavedFiles()
+    bool stashNewUnsavedFiles() const
     {
         return m_stashNewUnsavedFiles;
     }
@@ -43,12 +42,14 @@ public:
         m_stashNewUnsavedFiles = stashNewUnsavedFiles;
     }
 
-    void stashDocuments(KConfig *cfg, const QList<KTextEditor::Document *> &documents);
+    bool canStash() const;
+
+    void stashDocuments(KConfig *cfg, const QList<KTextEditor::Document *> &documents) const;
 
     bool willStashDoc(KTextEditor::Document *doc) const;
 
-    void stashDocument(KTextEditor::Document *doc, const QString &stashfileName, KConfigGroup &kconfig, const QString &path);
-    static bool popDocument(KTextEditor::Document *doc, const KConfigGroup &kconfig);
+    void stashDocument(KTextEditor::Document *doc, const QString &stashfileName, KConfigGroup &kconfig, const QString &path) const;
+    static void popDocument(KTextEditor::Document *doc, const KConfigGroup &kconfig);
 
     static void clearStashForSession(const KateSession::Ptr session);
 
@@ -56,5 +57,3 @@ private:
     bool m_stashUnsavedChanges = false;
     bool m_stashNewUnsavedFiles = true;
 };
-
-#endif // KATESTASHMANAGER_H
